@@ -19,15 +19,16 @@
     var self = this;
 
     fetch(self.url_prefix + '/session/')
-      .then(function (response) { })
-      .then(function (data) {
-        if (data.status == 'ok') {
-          self.sesison = data.session;
-        } else {
-          console.error('Failed to load session');
-        }
+      .then(function (response) {
+        response.json().then(function (data) {
+          if (data.status == 'ok') {
+            self.session = data.session;
+          } else {
+            console.error('Failed to load session');
+          }
 
-        callback(this);
+          callback(this);
+        });
       });
   }
 
@@ -41,6 +42,7 @@
   Subscription.prototype.subscribe = function (stripeToken, plan_id, on_success, on_error)
   {
     var formData = new FormData();
+    var self = this;
 
     formData.append('csrfmiddlewaretoken', this.session.csrf_token);
     formData.append('stripe_token', stripeToken);
@@ -51,13 +53,13 @@
         body: formData
       })
       .then(function (response) {
-      })
-      .then(function (data) {
-        if (data.status == 'ok') {
-          on_success(data);
-        } else {
-          on_error(data);
-        }
+        response.json().then(function (data) {
+          if (data.status == 'ok') {
+            on_success(data);
+          } else {
+            on_error(data);
+          }
+        });
       })
       .error(function (error) {
         on_error(error);
